# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DetectionDetectionEvent(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'RimeUUID',
        'project_id': 'RimeUUID',
        'firewall_id': 'RimeUUID',
        'event_type': 'DetectionEventType',
        'severity': 'RimeSeverity',
        'event_object_id': 'str',
        'event_object_name': 'str',
        'event_time_range': 'RimeTimeInterval',
        'last_update_time': 'datetime',
        'risk_category_type': 'RiskscoreRiskCategoryType',
        'test_category': 'TestrunTestCategoryType',
        'description': 'str',
        'description_html': 'str',
        'resolution': 'DetectionResolution',
        'detail': 'DetectionEventDetail'
    }

    attribute_map = {
        'id': 'id',
        'project_id': 'projectId',
        'firewall_id': 'firewallId',
        'event_type': 'eventType',
        'severity': 'severity',
        'event_object_id': 'eventObjectId',
        'event_object_name': 'eventObjectName',
        'event_time_range': 'eventTimeRange',
        'last_update_time': 'lastUpdateTime',
        'risk_category_type': 'riskCategoryType',
        'test_category': 'testCategory',
        'description': 'description',
        'description_html': 'descriptionHtml',
        'resolution': 'resolution',
        'detail': 'detail'
    }

    def __init__(self, id=None, project_id=None, firewall_id=None, event_type=None, severity=None, event_object_id=None, event_object_name=None, event_time_range=None, last_update_time=None, risk_category_type=None, test_category=None, description=None, description_html=None, resolution=None, detail=None):  # noqa: E501
        """DetectionDetectionEvent - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._project_id = None
        self._firewall_id = None
        self._event_type = None
        self._severity = None
        self._event_object_id = None
        self._event_object_name = None
        self._event_time_range = None
        self._last_update_time = None
        self._risk_category_type = None
        self._test_category = None
        self._description = None
        self._description_html = None
        self._resolution = None
        self._detail = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if project_id is not None:
            self.project_id = project_id
        if firewall_id is not None:
            self.firewall_id = firewall_id
        if event_type is not None:
            self.event_type = event_type
        if severity is not None:
            self.severity = severity
        if event_object_id is not None:
            self.event_object_id = event_object_id
        if event_object_name is not None:
            self.event_object_name = event_object_name
        if event_time_range is not None:
            self.event_time_range = event_time_range
        if last_update_time is not None:
            self.last_update_time = last_update_time
        if risk_category_type is not None:
            self.risk_category_type = risk_category_type
        if test_category is not None:
            self.test_category = test_category
        if description is not None:
            self.description = description
        if description_html is not None:
            self.description_html = description_html
        if resolution is not None:
            self.resolution = resolution
        if detail is not None:
            self.detail = detail

    @property
    def id(self):
        """Gets the id of this DetectionDetectionEvent.  # noqa: E501


        :return: The id of this DetectionDetectionEvent.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DetectionDetectionEvent.


        :param id: The id of this DetectionDetectionEvent.  # noqa: E501
        :type: RimeUUID
        """

        self._id = id

    @property
    def project_id(self):
        """Gets the project_id of this DetectionDetectionEvent.  # noqa: E501


        :return: The project_id of this DetectionDetectionEvent.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this DetectionDetectionEvent.


        :param project_id: The project_id of this DetectionDetectionEvent.  # noqa: E501
        :type: RimeUUID
        """

        self._project_id = project_id

    @property
    def firewall_id(self):
        """Gets the firewall_id of this DetectionDetectionEvent.  # noqa: E501


        :return: The firewall_id of this DetectionDetectionEvent.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._firewall_id

    @firewall_id.setter
    def firewall_id(self, firewall_id):
        """Sets the firewall_id of this DetectionDetectionEvent.


        :param firewall_id: The firewall_id of this DetectionDetectionEvent.  # noqa: E501
        :type: RimeUUID
        """

        self._firewall_id = firewall_id

    @property
    def event_type(self):
        """Gets the event_type of this DetectionDetectionEvent.  # noqa: E501


        :return: The event_type of this DetectionDetectionEvent.  # noqa: E501
        :rtype: DetectionEventType
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """Sets the event_type of this DetectionDetectionEvent.


        :param event_type: The event_type of this DetectionDetectionEvent.  # noqa: E501
        :type: DetectionEventType
        """

        self._event_type = event_type

    @property
    def severity(self):
        """Gets the severity of this DetectionDetectionEvent.  # noqa: E501


        :return: The severity of this DetectionDetectionEvent.  # noqa: E501
        :rtype: RimeSeverity
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """Sets the severity of this DetectionDetectionEvent.


        :param severity: The severity of this DetectionDetectionEvent.  # noqa: E501
        :type: RimeSeverity
        """

        self._severity = severity

    @property
    def event_object_id(self):
        """Gets the event_object_id of this DetectionDetectionEvent.  # noqa: E501

        The event object varies with the event type. CT and security events use a monitor. Offline Test events use the test run.  # noqa: E501

        :return: The event_object_id of this DetectionDetectionEvent.  # noqa: E501
        :rtype: str
        """
        return self._event_object_id

    @event_object_id.setter
    def event_object_id(self, event_object_id):
        """Sets the event_object_id of this DetectionDetectionEvent.

        The event object varies with the event type. CT and security events use a monitor. Offline Test events use the test run.  # noqa: E501

        :param event_object_id: The event_object_id of this DetectionDetectionEvent.  # noqa: E501
        :type: str
        """

        self._event_object_id = event_object_id

    @property
    def event_object_name(self):
        """Gets the event_object_name of this DetectionDetectionEvent.  # noqa: E501

        event_object_name to avoid extra query from UI to display, and allow easier search support with DB. If the event object is renamed, the event will not be updated.  # noqa: E501

        :return: The event_object_name of this DetectionDetectionEvent.  # noqa: E501
        :rtype: str
        """
        return self._event_object_name

    @event_object_name.setter
    def event_object_name(self, event_object_name):
        """Sets the event_object_name of this DetectionDetectionEvent.

        event_object_name to avoid extra query from UI to display, and allow easier search support with DB. If the event object is renamed, the event will not be updated.  # noqa: E501

        :param event_object_name: The event_object_name of this DetectionDetectionEvent.  # noqa: E501
        :type: str
        """

        self._event_object_name = event_object_name

    @property
    def event_time_range(self):
        """Gets the event_time_range of this DetectionDetectionEvent.  # noqa: E501


        :return: The event_time_range of this DetectionDetectionEvent.  # noqa: E501
        :rtype: RimeTimeInterval
        """
        return self._event_time_range

    @event_time_range.setter
    def event_time_range(self, event_time_range):
        """Sets the event_time_range of this DetectionDetectionEvent.


        :param event_time_range: The event_time_range of this DetectionDetectionEvent.  # noqa: E501
        :type: RimeTimeInterval
        """

        self._event_time_range = event_time_range

    @property
    def last_update_time(self):
        """Gets the last_update_time of this DetectionDetectionEvent.  # noqa: E501


        :return: The last_update_time of this DetectionDetectionEvent.  # noqa: E501
        :rtype: datetime
        """
        return self._last_update_time

    @last_update_time.setter
    def last_update_time(self, last_update_time):
        """Sets the last_update_time of this DetectionDetectionEvent.


        :param last_update_time: The last_update_time of this DetectionDetectionEvent.  # noqa: E501
        :type: datetime
        """

        self._last_update_time = last_update_time

    @property
    def risk_category_type(self):
        """Gets the risk_category_type of this DetectionDetectionEvent.  # noqa: E501


        :return: The risk_category_type of this DetectionDetectionEvent.  # noqa: E501
        :rtype: RiskscoreRiskCategoryType
        """
        return self._risk_category_type

    @risk_category_type.setter
    def risk_category_type(self, risk_category_type):
        """Sets the risk_category_type of this DetectionDetectionEvent.


        :param risk_category_type: The risk_category_type of this DetectionDetectionEvent.  # noqa: E501
        :type: RiskscoreRiskCategoryType
        """

        self._risk_category_type = risk_category_type

    @property
    def test_category(self):
        """Gets the test_category of this DetectionDetectionEvent.  # noqa: E501


        :return: The test_category of this DetectionDetectionEvent.  # noqa: E501
        :rtype: TestrunTestCategoryType
        """
        return self._test_category

    @test_category.setter
    def test_category(self, test_category):
        """Sets the test_category of this DetectionDetectionEvent.


        :param test_category: The test_category of this DetectionDetectionEvent.  # noqa: E501
        :type: TestrunTestCategoryType
        """

        self._test_category = test_category

    @property
    def description(self):
        """Gets the description of this DetectionDetectionEvent.  # noqa: E501

        Human-readable description of the event.  # noqa: E501

        :return: The description of this DetectionDetectionEvent.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this DetectionDetectionEvent.

        Human-readable description of the event.  # noqa: E501

        :param description: The description of this DetectionDetectionEvent.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def description_html(self):
        """Gets the description_html of this DetectionDetectionEvent.  # noqa: E501

        Description of the event with HTML for nicer rendering.  # noqa: E501

        :return: The description_html of this DetectionDetectionEvent.  # noqa: E501
        :rtype: str
        """
        return self._description_html

    @description_html.setter
    def description_html(self, description_html):
        """Sets the description_html of this DetectionDetectionEvent.

        Description of the event with HTML for nicer rendering.  # noqa: E501

        :param description_html: The description_html of this DetectionDetectionEvent.  # noqa: E501
        :type: str
        """

        self._description_html = description_html

    @property
    def resolution(self):
        """Gets the resolution of this DetectionDetectionEvent.  # noqa: E501


        :return: The resolution of this DetectionDetectionEvent.  # noqa: E501
        :rtype: DetectionResolution
        """
        return self._resolution

    @resolution.setter
    def resolution(self, resolution):
        """Sets the resolution of this DetectionDetectionEvent.


        :param resolution: The resolution of this DetectionDetectionEvent.  # noqa: E501
        :type: DetectionResolution
        """

        self._resolution = resolution

    @property
    def detail(self):
        """Gets the detail of this DetectionDetectionEvent.  # noqa: E501


        :return: The detail of this DetectionDetectionEvent.  # noqa: E501
        :rtype: DetectionEventDetail
        """
        return self._detail

    @detail.setter
    def detail(self, detail):
        """Sets the detail of this DetectionDetectionEvent.


        :param detail: The detail of this DetectionDetectionEvent.  # noqa: E501
        :type: DetectionEventDetail
        """

        self._detail = detail

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DetectionDetectionEvent, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DetectionDetectionEvent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



"""Library that defines the interface to the Registry."""
import json
import logging
from http import HTTPStatus
from typing import Dict, Iterator, List, Optional, Tuple, cast

from deprecated import deprecated

from rime_sdk.internal.config_parser import (
    convert_model_info_to_swagger,
    convert_single_data_info_to_swagger,
    convert_single_pred_info_to_swagger,
)
from rime_sdk.internal.rest_error_handler import RESTErrorHandler
from rime_sdk.internal.swagger_utils import serialize_datetime_to_proto_timestamp
from rime_sdk.job import Job
from rime_sdk.swagger import swagger_client
from rime_sdk.swagger.swagger_client import (
    ApiClient,
    DatasetCTDatasetType,
    DatasetCTInfo,
)
from rime_sdk.swagger.swagger_client.models import (
    DatasetIdPredictionBody,
    ProjectIdUuidDatasetBody,
    ProjectIdUuidModelBody,
    RegistryMetadata,
    RegistryValidityStatus,
    RimeGetDatasetResponse,
    RimeGetModelResponse,
    RimeGetPredictionSetResponse,
    RimeListDatasetsResponse,
    RimeListModelsResponse,
    RimeListPredictionSetsResponse,
    RimeRegisterDatasetResponse,
    RimeRegisterModelResponse,
    RimeRegisterPredictionSetResponse,
    RimeUUID,
)
from rime_sdk.swagger.swagger_client.rest import ApiException

logger = logging.getLogger(__name__)


class Registry:
    """An interface to a RIME Registry."""

    def __init__(self, api_client: ApiClient) -> None:
        """Create a new Registry object.

        Arguments:
            api_client: ApiClient
                The client used to query the RIME cluster.
        """
        self._api_client = api_client

    @deprecated(
        "register_dataset is replaced by register_and_validate_dataset and will be removed in a future release."
    )
    def register_dataset(
        self,
        project_id: str,
        name: str,
        data_config: dict,
        integration_id: Optional[str] = None,
        tags: Optional[List[str]] = None,
        metadata: Optional[dict] = None,
        ct_info: Optional[dict] = None,
        skip_validation: Optional[bool] = False,  # noqa: ARG002
        agent_id: Optional[str] = None,
    ) -> str:
        """Register and validate a new dataset in a Project.

        Args:
            project_id: str
                The ID of the Project in which to register the dataset.
            name: str
                The chosen name of the dataset.
            data_config: dict
                A dictionary that contains the data configuration.
                The data configuration must match the API specification
                of the `data_info` field in the `RegisterDataset` request.
            integration_id: Optional[str] = None,
                Provide the integration ID for datasets that require an integration.
            tags: Optional[List[str]] = None,
                An optional list of tags to associate with the dataset.
            metadata: Optional[dict] = None,
                An optional dictionary of metadata to associate with the dataset.
            ct_info: Optional[dict] = None,
                An optional dictionary that contains the CT info.
                The CT info must match the API specification of the `ct_info`
                field in the `RegisterDataset` request.
            skip_validation: Optional[bool] = False,
                The param is deprecated, validate is always performed.
            agent_id: Optional[str] = None,
                Agent for running validation. If omitted the workspace's default
                agent will be used.

        Returns:
            str:
                The ID of the newly registered dataset.

        Raises:
            ValueError
                This error is generated when the request to the Registry
                service fails.

        Example:
            .. code-block:: python

                dataset_id = registry.register_dataset(
                    name=DATASET_NAME,
                    data_config={
                        "connection_info": {"data_file": {"path": FILE_PATH}},
                        "data_params": {"label_col": LABEL_COL},
                    },
                    integration_id=INTEGRATION_ID,
                )
        """
        dataset_id, _ = self.register_and_validate_dataset(
            project_id=project_id,
            name=name,
            data_config=data_config,
            integration_id=integration_id,
            tags=tags,
            metadata=metadata,
            ct_info=ct_info,
            agent_id=agent_id,
        )
        return dataset_id

    def register_and_validate_dataset(
        self,
        project_id: str,
        name: str,
        data_config: dict,
        integration_id: Optional[str] = None,
        tags: Optional[List[str]] = None,
        metadata: Optional[dict] = None,
        ct_info: Optional[dict] = None,
        agent_id: Optional[str] = None,
    ) -> Tuple[str, Optional[Job]]:
        """Register and validate a new dataset in a Project.

        Args:
            project_id: str
                The ID of the Project in which to register the dataset.
            name: str
                The chosen name of the dataset.
            data_config: dict
                A dictionary that contains the data configuration.
                The data configuration must match the API specification
                of the `data_info` field in the `RegisterDataset` request.
            integration_id: Optional[str] = None,
                Provide the integration ID for datasets that require an integration.
            tags: Optional[List[str]] = None,
                An optional list of tags to associate with the dataset.
            metadata: Optional[dict] = None,
                An optional dictionary of metadata to associate with the dataset.
            ct_info: Optional[dict] = None,
                An optional dictionary that contains the CT info.
                The CT info must match the API specification of the `ct_info`
                field in the `RegisterDataset` request.
            agent_id: Optional[str] = None,
                Agent for running validation. If omitted the workspace's default
                agent will be used.

        Returns:
            str:
                The ID of the newly registered dataset.
            job:
                The job object that represents the validation job.

        Raises:
            ValueError
                This error is generated when the request to the Registry
                service fails.

        Example:
            .. code-block:: python

                dataset_id = registry.register_dataset(
                    name=DATASET_NAME,
                    data_config={
                        "connection_info": {"data_file": {"path": FILE_PATH}},
                        "data_params": {"label_col": LABEL_COL},
                    },
                    integration_id=INTEGRATION_ID,
                )
        """
        data_info_swagger = convert_single_data_info_to_swagger(data_config)
        req = ProjectIdUuidDatasetBody(
            project_id=RimeUUID(uuid=project_id),
            name=name,
            data_info=data_info_swagger,
            agent_id=RimeUUID(agent_id) if agent_id else None,
        )

        metadata_str: Optional[str] = None
        if metadata is not None:
            metadata_str = json.dumps(metadata)
        if tags is not None or metadata_str is not None:
            req.metadata = RegistryMetadata(tags=tags, extra_info=metadata_str)

        if integration_id is not None:
            req.integration_id = RimeUUID(uuid=integration_id)

        if ct_info is not None:
            req.ct_info = DatasetCTInfo(
                firewall_id=RimeUUID(uuid=ct_info["firewall_id"]),
                start_time=serialize_datetime_to_proto_timestamp(ct_info["start_time"]),
                end_time=serialize_datetime_to_proto_timestamp(ct_info["end_time"]),
                ct_dataset_type=DatasetCTDatasetType.USER_SPECIFIED,
            )

        with RESTErrorHandler():
            api = swagger_client.RegistryServiceApi(self._api_client)
            res = api.registry_service_register_dataset(
                body=req,
                project_id_uuid=project_id,
            )

            res = cast(RimeRegisterDatasetResponse, res)

        return (
            res.dataset_id,
            Job(self._api_client, res.registry_validation_job_id.uuid)
            if res.registry_validation_job_id
            else None,
        )

    @deprecated(
        "register_model is replaced by register_and_validate_model and will be removed in a future release."
    )
    def register_model(
        self,
        project_id: str,
        name: str,
        model_config: Optional[dict] = None,
        tags: Optional[List[str]] = None,
        metadata: Optional[dict] = None,
        external_id: Optional[str] = None,
        integration_id: Optional[str] = None,
        model_endpoint_integration_id: Optional[str] = None,
        skip_validation: Optional[bool] = False,  # noqa: ARG002
        agent_id: Optional[str] = None,
    ) -> str:
        """Register and validate a new model in a Project.

        Args:
            project_id: str
                The ID of the Project in which to register the model.
            name: str
                The chosen name of the model.
            model_config: Optional[dict] = None,
                A dictionary that contains the model configuration.
                Any model configuration that is provided must match the API
                specification for the `model_info` field of the `RegisterModel`
                request.
            tags: Optional[List[str]] = None,
                An optional list of tags to associate with the model.
            metadata: Optional[dict] = None,
                An optional dictionary of metadata to associate with the model.
            external_id: Optional[str] = None,
                An optional external ID that can be used to identify the model.
            integration_id: Optional[str] = None,
                Provide the integration ID for models that require an
                integration for access.
            model_endpoint_integration_id: Optional[str] = None,
                Provide the integration ID for models that require an
                integration when running the model.
            skip_validation: Optional[bool] = False,
                The param is deprecated, validate is always performed.
            agent_id: Optional[str] = None,
                Agent for running validation. If omitted the workspace's default
                agent will be used.

        Returns:
            str:
                The ID of the newly registered model.

        Raises:
            ValueError
                This error is generated when the request to the Registry
                service fails.

        Example:
            .. code-block:: python

                model_id = registry.register_model(
                    name=MODEL_NAME,
                    model_config={
                        "hugging_face": {
                            "model_uri": URI,
                            "kwargs": {
                                "tokenizer_uri": TOKENIZER_URI,
                                "class_map": MAP,
                                "ignore_class_names": True,
                            },
                        }
                    },
                    tags=[MODEL_TAG],
                    metadata={KEY: VALUE},
                    external_id=EXTERNAL_ID,
                    agent_id=AGENT_ID,
                )
        """
        model_id, _ = self.register_and_validate_model(
            project_id=project_id,
            name=name,
            model_config=model_config,
            tags=tags,
            metadata=metadata,
            external_id=external_id,
            integration_id=integration_id,
            model_endpoint_integration_id=model_endpoint_integration_id,
            agent_id=agent_id,
        )
        return model_id

    def register_and_validate_model(
        self,
        project_id: str,
        name: str,
        model_config: Optional[dict] = None,
        tags: Optional[List[str]] = None,
        metadata: Optional[dict] = None,
        external_id: Optional[str] = None,
        integration_id: Optional[str] = None,
        model_endpoint_integration_id: Optional[str] = None,
        agent_id: Optional[str] = None,
    ) -> Tuple[str, Optional[Job]]:
        """Register and validate a new model in a Project.

        Args:
            project_id: str
                The ID of the Project in which to register the model.
            name: str
                The chosen name of the model.
            model_config: Optional[dict] = None,
                A dictionary that contains the model configuration.
                Any model configuration that is provided must match the API
                specification for the `model_info` field of the `RegisterModel`
                request.
            tags: Optional[List[str]] = None,
                An optional list of tags to associate with the model.
            metadata: Optional[dict] = None,
                An optional dictionary of metadata to associate with the model.
            external_id: Optional[str] = None,
                An optional external ID that can be used to identify the model.
            integration_id: Optional[str] = None,
                Provide the integration ID for models that require an
                integration for access.
            model_endpoint_integration_id: Optional[str] = None,
                Provide the integration ID for models that require an
                integration when running the model.
            agent_id: Optional[str] = None,
                Agent for running validation. If omitted the workspace's default
                agent will be used.

        Returns:
            str:
                The ID of the newly registered model.
            job:
                The job object that represents the validation job.

        Raises:
            ValueError
                This error is generated when the request to the Registry
                service fails.

        Example:
            .. code-block:: python

                model_id = registry.register_model(
                    name=MODEL_NAME,
                    model_config={
                        "hugging_face": {
                            "model_uri": URI,
                            "kwargs": {
                                "tokenizer_uri": TOKENIZER_URI,
                                "class_map": MAP,
                                "ignore_class_names": True,
                            },
                        }
                    },
                    tags=[MODEL_TAG],
                    metadata={KEY: VALUE},
                    external_id=EXTERNAL_ID,
                    agent_id=AGENT_ID,
                )
        """
        req = ProjectIdUuidModelBody(
            project_id=RimeUUID(uuid=project_id),
            name=name,
            agent_id=RimeUUID(agent_id) if agent_id else None,
        )

        if model_config is not None:
            # When the `model_path` key is provided to the dictionary, the value
            # must be a dictionary whose `path` value points to a python
            # file that holds a `predict_dict` or `predict_df` function.
            # When the `model_loading` key is provided to the dictionary, the value
            # must be a dictionary whose `path` value points to a python
            # file that holds a `get_predict_df` or `get_predict_dict` function and
            # whose value for the `params` key is a dictionary of parameters to
            # pass to the function.
            # When the `hugging_face` key is provided to the dictionary, the value must
            # be a dictionary whose `model_uri` value points to a
            # hugging face model and whose value for the `params` key is a dictionary
            # of parameters that hugging face model requires.
            model_info = convert_model_info_to_swagger(model_config)
            req.model_info = model_info

        metadata_str: Optional[str] = None
        if metadata:
            metadata_str = json.dumps(metadata)
        if tags or metadata_str:
            req.metadata = RegistryMetadata(tags=tags, extra_info=metadata_str)
        if external_id:
            req.external_id = external_id
        if integration_id is not None:
            req.integration_id = RimeUUID(uuid=integration_id)
        if model_endpoint_integration_id is not None:
            req.model_endpoint_integration_id = RimeUUID(
                uuid=model_endpoint_integration_id
            )

        with RESTErrorHandler():
            api = swagger_client.RegistryServiceApi(self._api_client)
            res = api.registry_service_register_model(
                body=req,
                project_id_uuid=project_id,
            )

            res = cast(RimeRegisterModelResponse, res)

        return (
            cast(RimeUUID, res.model_id).uuid,
            Job(self._api_client, res.registry_validation_job_id.uuid)
            if res.registry_validation_job_id
            else None,
        )

    @deprecated(
        "register_predictions is replaced by register_and_validate_prediction and will be removed in a future release."
    )
    def register_predictions(
        self,
        project_id: str,
        dataset_id: str,
        model_id: str,
        pred_config: dict,
        integration_id: Optional[str] = None,
        tags: Optional[List[str]] = None,
        metadata: Optional[dict] = None,
        skip_validation: Optional[bool] = False,  # noqa: ARG002
        agent_id: Optional[str] = None,
    ) -> None:
        """Register and validate a new set of predictions for a model and a dataset.

        Args:
            project_id: str
                The ID of the Project to which the models belong.
            dataset_id: str,
                The ID of the dataset used to generate the predictions.
            model_id: str,
                The ID of the model used to generate the predictions.
            pred_config: dict,
                A dictionary that contains the prediction configuration.
                The prediction configuration must match the API specification
                for the `pred_info` field of the `RegisterPredictions` request.
            integration_id: Optional[str] = None,
                Provide the integration ID for predictions that require an
                integration to use.
            tags: Optional[List[str]] = None,
                An optional list of tags to associate with the predictions.
            metadata: Optional[dict] = None,
                An optional dictionary of metadata to associate with the predictions.
            skip_validation: Optional[bool] = False,
                The param is deprecated, validate is always performed.
            agent_id: Optional[str] = None,
                Agent for running validation. If omitted the workspace's default
                agent will be used.

        Returns:
            None

        Raises:
            ValueError
                This error is generated when the request to the Registry
                service fails.

        Example:
            .. code-block:: python

                registry.register_predictions(
                    dataset_id=DATASET_ID,
                    model_id=MODEL_ID,
                    pred_config={
                        "connection_info": {
                            "databricks": {
                                # Unix timestamp equivalent to 02/08/2023
                                "start_time": 1675922943,
                                # Unix timestamp equivalent to 03/08/2023
                                "end_time": 1678342145,
                                "table_name": TABLE_NAME,
                                "time_col": TIME_COL,
                            },
                        },
                        "pred_params": {"pred_col": PREDS},
                    },
                    tags=[TAG],
                    metadata={KEY: VALUE},
                )
        """
        self.register_and_validate_predictions(
            project_id=project_id,
            dataset_id=dataset_id,
            model_id=model_id,
            pred_config=pred_config,
            integration_id=integration_id,
            tags=tags,
            metadata=metadata,
            agent_id=agent_id,
        )

    def register_and_validate_predictions(
        self,
        project_id: str,
        dataset_id: str,
        model_id: str,
        pred_config: dict,
        integration_id: Optional[str] = None,
        tags: Optional[List[str]] = None,
        metadata: Optional[dict] = None,
        agent_id: Optional[str] = None,
    ) -> Optional[Job]:
        """Register and validate a new set of predictions for a model and a dataset.

        Args:
            project_id: str
                The ID of the Project to which the models belong.
            dataset_id: str,
                The ID of the dataset used to generate the predictions.
            model_id: str,
                The ID of the model used to generate the predictions.
            pred_config: dict,
                A dictionary that contains the prediction configuration.
                The prediction configuration must match the API specification
                for the `pred_info` field of the `RegisterPredictions` request.
            integration_id: Optional[str] = None,
                Provide the integration ID for predictions that require an
                integration to use.
            tags: Optional[List[str]] = None,
                An optional list of tags to associate with the predictions.
            metadata: Optional[dict] = None,
                An optional dictionary of metadata to associate with the predictions.
            skip_validation: Optional[bool] = False,
                An optional boolean that indicates whether to skip validation.
                Validation ensures that the predictions are valid for Robust
                Intelligence's systems.
            agent_id: Optional[str] = None,
                Agent for running validation. If omitted the workspace's default
                agent will be used.

        Returns:
            job:
                The job object that represents the validation job.

        Raises:
            ValueError
                This error is generated when the request to the Registry
                service fails.

        Example:
            .. code-block:: python

                registry.register_predictions(
                    dataset_id=DATASET_ID,
                    model_id=MODEL_ID,
                    pred_config={
                        "connection_info": {
                            "databricks": {
                                # Unix timestamp equivalent to 02/08/2023
                                "start_time": 1675922943,
                                # Unix timestamp equivalent to 03/08/2023
                                "end_time": 1678342145,
                                "table_name": TABLE_NAME,
                                "time_col": TIME_COL,
                            },
                        },
                        "pred_params": {"pred_col": PREDS},
                    },
                    tags=[TAG],
                    metadata={KEY: VALUE},
                )
        """
        pred_info_swagger = convert_single_pred_info_to_swagger(pred_config)

        req = DatasetIdPredictionBody(
            project_id=RimeUUID(uuid=project_id),
            model_id=RimeUUID(uuid=model_id),
            pred_info=pred_info_swagger,
            agent_id=RimeUUID(agent_id) if agent_id else None,
        )

        metadata_str: Optional[str] = None
        if metadata is not None:
            metadata_str = json.dumps(metadata)
        if tags is not None or metadata_str is not None:
            req.metadata = RegistryMetadata(tags=tags, extra_info=metadata_str)

        if integration_id is not None:
            req.integration_id = RimeUUID(uuid=integration_id)

        with RESTErrorHandler():
            api = swagger_client.RegistryServiceApi(self._api_client)
            res = api.registry_service_register_prediction_set(
                body=req,
                project_id_uuid=project_id,
                model_id_uuid=model_id,
                dataset_id=dataset_id,
            )
        res = cast(RimeRegisterPredictionSetResponse, res)
        return (
            Job(self._api_client, res.registry_validation_job_id.uuid)
            if res.registry_validation_job_id
            else None
        )

    def list_datasets(self, project_id: str) -> Iterator[Dict]:
        """Return a list of datasets.

        Args:
            project_id: str
                The ID of the Project to which the datasets belong.

        Returns:
            Iterator[Dict]:
                Iterator of dictionaries: each dictionary represents a
                dataset.

        Raises:
            ValueError
                This error is generated when the request to the Registry
                service fails.
        """
        api = swagger_client.RegistryServiceApi(self._api_client)
        # Iterate through the pages of datasets and break at the last page.
        page_token = ""
        with RESTErrorHandler():
            while True:
                if page_token == "":
                    res: RimeListDatasetsResponse = api.registry_service_list_datasets(
                        project_id_uuid=project_id
                    )
                else:
                    res = api.registry_service_list_datasets(
                        project_id_uuid=project_id, page_token=page_token
                    )
                if res.datasets is not None:
                    for dataset in res.datasets:
                        yield dataset.to_dict()
                # Advance to the next page of datasets.
                page_token = res.next_page_token
                # we've reached the last page of datasets.
                if not res.has_more:
                    break

    def list_models(self, project_id: str) -> Iterator[Dict]:
        """Return a list of models.

        Args:
            project_id: str
                The ID of the Project to which the models belong.

        Returns:
            Iterator[Dict]:
                Iterator of dictionaries: each dictionary represents a
                model.

        Raises:
            ValueError
                This error is generated when the request to the Registry
                service fails.
        """
        api = swagger_client.RegistryServiceApi(self._api_client)
        # Iterate through the pages of datasets and break at the last page.
        page_token = ""
        with RESTErrorHandler():
            while True:
                if page_token == "":
                    res: RimeListModelsResponse = api.registry_service_list_models(
                        project_id_uuid=project_id
                    )
                else:
                    res = api.registry_service_list_models(
                        project_id_uuid=project_id, page_token=page_token
                    )
                if res.models is not None:
                    for model in res.models:
                        yield model.model.to_dict()
                # Advance to the next page of models.
                page_token = res.next_page_token
                # we've reached the last page of models.
                if not res.has_more:
                    break

    def list_predictions(
        self,
        project_id: str,
        model_id: Optional[str] = None,
        dataset_id: Optional[str] = None,
    ) -> Iterator[Dict]:
        """Return a list of prediction sets.

        Args:
            project_id: str
                The ID of the Project to which the models belong.
            model_id: Optional[str] = None
                The ID of the model to which the prediction sets belong.
            dataset_id: Optional[str] = None
                The ID of the dataset to which the prediction sets belong.

        Returns:
            Iterator[Dict]:
                Iterator of dictionaries: each dictionary represents a
                prediction set.

        Raises:
            ValueError
                This error is generated when the request to the Registry
                service fails.
        """
        if model_id is not None and dataset_id is not None:
            raise ValueError("Only one of model_id or dataset_id can be set.")
        if model_id is None and dataset_id is None:
            raise ValueError("Must specify either a model_id or dataset_id.")
        else:
            pass
        api = swagger_client.RegistryServiceApi(self._api_client)
        # Iterate through the pages of datasets and break at the last page.
        page_token = ""
        with RESTErrorHandler():
            while True:
                if page_token == "":
                    if model_id is not None:
                        res: RimeListPredictionSetsResponse = (
                            api.registry_service_list_prediction_sets(
                                project_id_uuid=project_id,
                                first_page_req_model_id=model_id,
                            )
                        )
                    else:
                        res = api.registry_service_list_prediction_sets(
                            project_id_uuid=project_id,
                            first_page_req_dataset_id=dataset_id,
                        )
                else:
                    res = api.registry_service_list_prediction_sets(
                        project_id_uuid=project_id,
                        page_token=page_token,
                    )
                if res.predictions is not None:
                    for prediction in res.predictions:
                        yield prediction.to_dict()
                # Advance to the next page of predictions.
                page_token = res.next_page_token
                # we've reached the last page of predictions.
                if not res.has_more:
                    break

    def get_dataset(
        self, dataset_id: Optional[str] = None, dataset_name: Optional[str] = None
    ) -> Dict:
        """Return a dataset.

        Args:
            dataset_id: str
                The ID of the dataset to retrieve.
            dataset_name: str
                The name of the dataset to retrieve.

        Returns:
            Dict:
                A dictionary representing the dataset.

        Raises:
            ValueError
                This error is generated when the request to the Registry
                service fails.
        """
        if dataset_id is not None and dataset_name is not None:
            raise ValueError(
                "Arguments dataset_id and dataset_name"
                " are mutually exclusive.\n"
                f"Received dataset_id={dataset_id}"
                f" and dataset_name={dataset_name}."
            )
        elif dataset_name is None and dataset_id is None:
            raise ValueError("Must provide either dataset_id or dataset_name")
        api = swagger_client.RegistryServiceApi(self._api_client)
        with RESTErrorHandler():
            if dataset_id:
                res: RimeGetDatasetResponse = api.registry_service_get_dataset(
                    dataset_id=dataset_id
                )
            else:
                res = api.registry_service_get_dataset(dataset_name=dataset_name)
        return res.dataset.to_dict()

    def has_dataset(
        self, dataset_id: Optional[str] = None, dataset_name: Optional[str] = None
    ) -> bool:
        """Return a boolean on whether the dataset is present.

        Args:
            dataset_id: Optional[str] = None
                The ID of the dataset to check for.
            dataset_name: Optional[str] = None
                The name of the dataset to check for.

        Returns:
            bool:
                A boolean on whether the dataset is present.

        Raises:
            ValueError
                This error is generated any error other than HTTPStatus.NOT_FOUND
                is returned from the Registry service.
        """
        if dataset_id is not None and dataset_name is not None:
            raise ValueError(
                "Arguments dataset_id and dataset_name"
                " are mutually exclusive.\n"
                f"Received dataset_id={dataset_id}"
                f" and dataset_name={dataset_name}."
            )
        elif dataset_name is None and dataset_id is None:
            raise ValueError("Must provide either dataset_id or dataset_name")
        api = swagger_client.RegistryServiceApi(self._api_client)
        with RESTErrorHandler():
            try:
                if dataset_id:
                    api.registry_service_get_dataset(dataset_id=dataset_id)
                else:
                    api.registry_service_get_dataset(dataset_name=dataset_name)
            except ApiException as e:
                if e.status == HTTPStatus.NOT_FOUND:
                    return False
                else:
                    raise e
        return True

    def get_model(
        self, model_id: Optional[str] = None, model_name: Optional[str] = None
    ) -> Dict:
        """Return a model.

        Args:
            model_id: str
                The ID of the model to retrieve.
            model_name: str
                The name of the model to retrieve.

        Returns:
            Dict:
                A dictionary representing the model.

        Raises:
            ValueError
                This error is generated when the request to the Registry
                service fails.
        """
        api = swagger_client.RegistryServiceApi(self._api_client)
        with RESTErrorHandler():
            if model_id is not None:
                if model_name is not None:
                    raise ValueError(
                        "Arguments model_id and model_name are mutually exclusive.\n"
                        f"Received model_id={model_id} and model_name={model_name}."
                    )
                res: RimeGetModelResponse = api.registry_service_get_model(
                    model_id_uuid=model_id
                )
            elif model_name is not None:
                res = api.registry_service_get_model(model_name=model_name)
            else:
                raise ValueError("Must provide either model_id or model_name")
            return res.model.model.to_dict()

    def get_predictions(self, model_id: str, dataset_id: str) -> Dict:
        """Get a prediction set.

        Args:
            model_id: str
                The ID of the model used to generate the predictions.
            dataset_id: str
                The ID of the dataset used to generate the predictions.

        Returns:
            Dict:
                A dictionary that contains the prediction set.

        Raises:
            ValueError
                This error is generated when the request to the Registry
                service fails.
        """
        api = swagger_client.RegistryServiceApi(self._api_client)
        with RESTErrorHandler():
            res = api.registry_service_get_prediction_set(
                dataset_id=dataset_id, model_id_uuid=model_id
            )
            res = cast(RimeGetPredictionSetResponse, res)
            return res.prediction.to_dict()

    def delete_dataset(self, dataset_id: str) -> None:
        """Delete a dataset.

        Args:
            dataset_id: str
                The ID of the dataset to delete.

        Raises:
            ValueError
                This error is generated when the request to the Registry
                service fails.
        """
        api = swagger_client.RegistryServiceApi(self._api_client)
        with RESTErrorHandler():
            api.registry_service_delete_dataset(dataset_id=dataset_id)

    def delete_model(self, model_id: str) -> None:
        """Delete a model.

        Args:
            model_id: str
                The ID of the model to delete.

        Raises:
            ValueError
                This error is generated when the request to the Registry
                service fails.
        """
        api = swagger_client.RegistryServiceApi(self._api_client)
        with RESTErrorHandler():
            api.registry_service_delete_model(model_id_uuid=model_id)

    def delete_predictions(self, model_id: str, dataset_id: str) -> None:
        """Delete a prediction set.

        Args:
            model_id: str
                The ID of the model used to generate the predictions.
            dataset_id: str
                The ID of the dataset used to generate the predictions.

        Raises:
            ValueError
                This error is generated when the request to the Registry
                service fails.
        """
        api = swagger_client.RegistryServiceApi(self._api_client)
        with RESTErrorHandler():
            api.registry_service_delete_prediction_set(
                dataset_id=dataset_id, model_id_uuid=model_id
            )

    @staticmethod
    def log_registry_validation(
        registry_resp: dict, registry_type: str, registry_id: str
    ) -> None:
        """Log the validation status of a registry."""
        status = registry_resp.get(
            "validity_status", RegistryValidityStatus.UNSPECIFIED
        )
        if status != RegistryValidityStatus.VALID:
            print(
                f"Warning: the validation status of the {registry_type} {registry_id} is {status}. "
                f"Your test run may fail due to this {registry_type}.",
            )
            if registry_resp["validity_status_message"]:
                print(
                    f"The validation error message of the {registry_type} "
                    f"is {registry_resp['validity_status_message']}"
                )



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CrossplanetaskCrossPlaneResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'category_config_generation_service_response': 'ConfigGenerationCategoryConfigGenerationServiceResponse',
        'profiling_config_generation_service_response': 'ConfigGenerationProfilingConfigGenerationServiceResponse',
        'test_suite_config_generation_service_response': 'ConfigGenerationTestSuiteConfigGenerationServiceResponse',
        'check_object_exists_response': 'FileserverCheckObjectExistsResponse',
        'delete_object_response': 'FileserverDeleteObjectResponse',
        'get_read_object_presigned_link_response': 'FileserverGetReadObjectPresignedLinkResponse',
        'get_upload_object_presigned_link_response': 'FileserverGetUploadObjectPresignedLinkResponse',
        'list_objects_response': 'FileserverListObjectsResponse',
        'validate_dataset_response': 'ValidationValidateDatasetResponse',
        'validate_model_response': 'ValidationValidateModelResponse',
        'validate_predictions_response': 'ValidationValidatePredictionsResponse'
    }

    attribute_map = {
        'category_config_generation_service_response': 'categoryConfigGenerationServiceResponse',
        'profiling_config_generation_service_response': 'profilingConfigGenerationServiceResponse',
        'test_suite_config_generation_service_response': 'testSuiteConfigGenerationServiceResponse',
        'check_object_exists_response': 'checkObjectExistsResponse',
        'delete_object_response': 'deleteObjectResponse',
        'get_read_object_presigned_link_response': 'getReadObjectPresignedLinkResponse',
        'get_upload_object_presigned_link_response': 'getUploadObjectPresignedLinkResponse',
        'list_objects_response': 'listObjectsResponse',
        'validate_dataset_response': 'validateDatasetResponse',
        'validate_model_response': 'validateModelResponse',
        'validate_predictions_response': 'validatePredictionsResponse'
    }

    def __init__(self, category_config_generation_service_response=None, profiling_config_generation_service_response=None, test_suite_config_generation_service_response=None, check_object_exists_response=None, delete_object_response=None, get_read_object_presigned_link_response=None, get_upload_object_presigned_link_response=None, list_objects_response=None, validate_dataset_response=None, validate_model_response=None, validate_predictions_response=None):  # noqa: E501
        """CrossplanetaskCrossPlaneResponse - a model defined in Swagger"""  # noqa: E501
        self._category_config_generation_service_response = None
        self._profiling_config_generation_service_response = None
        self._test_suite_config_generation_service_response = None
        self._check_object_exists_response = None
        self._delete_object_response = None
        self._get_read_object_presigned_link_response = None
        self._get_upload_object_presigned_link_response = None
        self._list_objects_response = None
        self._validate_dataset_response = None
        self._validate_model_response = None
        self._validate_predictions_response = None
        self.discriminator = None
        if category_config_generation_service_response is not None:
            self.category_config_generation_service_response = category_config_generation_service_response
        if profiling_config_generation_service_response is not None:
            self.profiling_config_generation_service_response = profiling_config_generation_service_response
        if test_suite_config_generation_service_response is not None:
            self.test_suite_config_generation_service_response = test_suite_config_generation_service_response
        if check_object_exists_response is not None:
            self.check_object_exists_response = check_object_exists_response
        if delete_object_response is not None:
            self.delete_object_response = delete_object_response
        if get_read_object_presigned_link_response is not None:
            self.get_read_object_presigned_link_response = get_read_object_presigned_link_response
        if get_upload_object_presigned_link_response is not None:
            self.get_upload_object_presigned_link_response = get_upload_object_presigned_link_response
        if list_objects_response is not None:
            self.list_objects_response = list_objects_response
        if validate_dataset_response is not None:
            self.validate_dataset_response = validate_dataset_response
        if validate_model_response is not None:
            self.validate_model_response = validate_model_response
        if validate_predictions_response is not None:
            self.validate_predictions_response = validate_predictions_response

    @property
    def category_config_generation_service_response(self):
        """Gets the category_config_generation_service_response of this CrossplanetaskCrossPlaneResponse.  # noqa: E501


        :return: The category_config_generation_service_response of this CrossplanetaskCrossPlaneResponse.  # noqa: E501
        :rtype: ConfigGenerationCategoryConfigGenerationServiceResponse
        """
        return self._category_config_generation_service_response

    @category_config_generation_service_response.setter
    def category_config_generation_service_response(self, category_config_generation_service_response):
        """Sets the category_config_generation_service_response of this CrossplanetaskCrossPlaneResponse.


        :param category_config_generation_service_response: The category_config_generation_service_response of this CrossplanetaskCrossPlaneResponse.  # noqa: E501
        :type: ConfigGenerationCategoryConfigGenerationServiceResponse
        """

        self._category_config_generation_service_response = category_config_generation_service_response

    @property
    def profiling_config_generation_service_response(self):
        """Gets the profiling_config_generation_service_response of this CrossplanetaskCrossPlaneResponse.  # noqa: E501


        :return: The profiling_config_generation_service_response of this CrossplanetaskCrossPlaneResponse.  # noqa: E501
        :rtype: ConfigGenerationProfilingConfigGenerationServiceResponse
        """
        return self._profiling_config_generation_service_response

    @profiling_config_generation_service_response.setter
    def profiling_config_generation_service_response(self, profiling_config_generation_service_response):
        """Sets the profiling_config_generation_service_response of this CrossplanetaskCrossPlaneResponse.


        :param profiling_config_generation_service_response: The profiling_config_generation_service_response of this CrossplanetaskCrossPlaneResponse.  # noqa: E501
        :type: ConfigGenerationProfilingConfigGenerationServiceResponse
        """

        self._profiling_config_generation_service_response = profiling_config_generation_service_response

    @property
    def test_suite_config_generation_service_response(self):
        """Gets the test_suite_config_generation_service_response of this CrossplanetaskCrossPlaneResponse.  # noqa: E501


        :return: The test_suite_config_generation_service_response of this CrossplanetaskCrossPlaneResponse.  # noqa: E501
        :rtype: ConfigGenerationTestSuiteConfigGenerationServiceResponse
        """
        return self._test_suite_config_generation_service_response

    @test_suite_config_generation_service_response.setter
    def test_suite_config_generation_service_response(self, test_suite_config_generation_service_response):
        """Sets the test_suite_config_generation_service_response of this CrossplanetaskCrossPlaneResponse.


        :param test_suite_config_generation_service_response: The test_suite_config_generation_service_response of this CrossplanetaskCrossPlaneResponse.  # noqa: E501
        :type: ConfigGenerationTestSuiteConfigGenerationServiceResponse
        """

        self._test_suite_config_generation_service_response = test_suite_config_generation_service_response

    @property
    def check_object_exists_response(self):
        """Gets the check_object_exists_response of this CrossplanetaskCrossPlaneResponse.  # noqa: E501


        :return: The check_object_exists_response of this CrossplanetaskCrossPlaneResponse.  # noqa: E501
        :rtype: FileserverCheckObjectExistsResponse
        """
        return self._check_object_exists_response

    @check_object_exists_response.setter
    def check_object_exists_response(self, check_object_exists_response):
        """Sets the check_object_exists_response of this CrossplanetaskCrossPlaneResponse.


        :param check_object_exists_response: The check_object_exists_response of this CrossplanetaskCrossPlaneResponse.  # noqa: E501
        :type: FileserverCheckObjectExistsResponse
        """

        self._check_object_exists_response = check_object_exists_response

    @property
    def delete_object_response(self):
        """Gets the delete_object_response of this CrossplanetaskCrossPlaneResponse.  # noqa: E501


        :return: The delete_object_response of this CrossplanetaskCrossPlaneResponse.  # noqa: E501
        :rtype: FileserverDeleteObjectResponse
        """
        return self._delete_object_response

    @delete_object_response.setter
    def delete_object_response(self, delete_object_response):
        """Sets the delete_object_response of this CrossplanetaskCrossPlaneResponse.


        :param delete_object_response: The delete_object_response of this CrossplanetaskCrossPlaneResponse.  # noqa: E501
        :type: FileserverDeleteObjectResponse
        """

        self._delete_object_response = delete_object_response

    @property
    def get_read_object_presigned_link_response(self):
        """Gets the get_read_object_presigned_link_response of this CrossplanetaskCrossPlaneResponse.  # noqa: E501


        :return: The get_read_object_presigned_link_response of this CrossplanetaskCrossPlaneResponse.  # noqa: E501
        :rtype: FileserverGetReadObjectPresignedLinkResponse
        """
        return self._get_read_object_presigned_link_response

    @get_read_object_presigned_link_response.setter
    def get_read_object_presigned_link_response(self, get_read_object_presigned_link_response):
        """Sets the get_read_object_presigned_link_response of this CrossplanetaskCrossPlaneResponse.


        :param get_read_object_presigned_link_response: The get_read_object_presigned_link_response of this CrossplanetaskCrossPlaneResponse.  # noqa: E501
        :type: FileserverGetReadObjectPresignedLinkResponse
        """

        self._get_read_object_presigned_link_response = get_read_object_presigned_link_response

    @property
    def get_upload_object_presigned_link_response(self):
        """Gets the get_upload_object_presigned_link_response of this CrossplanetaskCrossPlaneResponse.  # noqa: E501


        :return: The get_upload_object_presigned_link_response of this CrossplanetaskCrossPlaneResponse.  # noqa: E501
        :rtype: FileserverGetUploadObjectPresignedLinkResponse
        """
        return self._get_upload_object_presigned_link_response

    @get_upload_object_presigned_link_response.setter
    def get_upload_object_presigned_link_response(self, get_upload_object_presigned_link_response):
        """Sets the get_upload_object_presigned_link_response of this CrossplanetaskCrossPlaneResponse.


        :param get_upload_object_presigned_link_response: The get_upload_object_presigned_link_response of this CrossplanetaskCrossPlaneResponse.  # noqa: E501
        :type: FileserverGetUploadObjectPresignedLinkResponse
        """

        self._get_upload_object_presigned_link_response = get_upload_object_presigned_link_response

    @property
    def list_objects_response(self):
        """Gets the list_objects_response of this CrossplanetaskCrossPlaneResponse.  # noqa: E501


        :return: The list_objects_response of this CrossplanetaskCrossPlaneResponse.  # noqa: E501
        :rtype: FileserverListObjectsResponse
        """
        return self._list_objects_response

    @list_objects_response.setter
    def list_objects_response(self, list_objects_response):
        """Sets the list_objects_response of this CrossplanetaskCrossPlaneResponse.


        :param list_objects_response: The list_objects_response of this CrossplanetaskCrossPlaneResponse.  # noqa: E501
        :type: FileserverListObjectsResponse
        """

        self._list_objects_response = list_objects_response

    @property
    def validate_dataset_response(self):
        """Gets the validate_dataset_response of this CrossplanetaskCrossPlaneResponse.  # noqa: E501


        :return: The validate_dataset_response of this CrossplanetaskCrossPlaneResponse.  # noqa: E501
        :rtype: ValidationValidateDatasetResponse
        """
        return self._validate_dataset_response

    @validate_dataset_response.setter
    def validate_dataset_response(self, validate_dataset_response):
        """Sets the validate_dataset_response of this CrossplanetaskCrossPlaneResponse.


        :param validate_dataset_response: The validate_dataset_response of this CrossplanetaskCrossPlaneResponse.  # noqa: E501
        :type: ValidationValidateDatasetResponse
        """

        self._validate_dataset_response = validate_dataset_response

    @property
    def validate_model_response(self):
        """Gets the validate_model_response of this CrossplanetaskCrossPlaneResponse.  # noqa: E501


        :return: The validate_model_response of this CrossplanetaskCrossPlaneResponse.  # noqa: E501
        :rtype: ValidationValidateModelResponse
        """
        return self._validate_model_response

    @validate_model_response.setter
    def validate_model_response(self, validate_model_response):
        """Sets the validate_model_response of this CrossplanetaskCrossPlaneResponse.


        :param validate_model_response: The validate_model_response of this CrossplanetaskCrossPlaneResponse.  # noqa: E501
        :type: ValidationValidateModelResponse
        """

        self._validate_model_response = validate_model_response

    @property
    def validate_predictions_response(self):
        """Gets the validate_predictions_response of this CrossplanetaskCrossPlaneResponse.  # noqa: E501


        :return: The validate_predictions_response of this CrossplanetaskCrossPlaneResponse.  # noqa: E501
        :rtype: ValidationValidatePredictionsResponse
        """
        return self._validate_predictions_response

    @validate_predictions_response.setter
    def validate_predictions_response(self, validate_predictions_response):
        """Sets the validate_predictions_response of this CrossplanetaskCrossPlaneResponse.


        :param validate_predictions_response: The validate_predictions_response of this CrossplanetaskCrossPlaneResponse.  # noqa: E501
        :type: ValidationValidatePredictionsResponse
        """

        self._validate_predictions_response = validate_predictions_response

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CrossplanetaskCrossPlaneResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CrossplanetaskCrossPlaneResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class FirewallinstanceFirewallInstanceFirewallInstanceIdUuidBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'firewall_instance_id': 'object',
        'config': 'GenerativefirewallFirewallRuleConfig',
        'deployment_status': 'GenerativefirewallFirewallInstanceStatus',
        'description': 'str'
    }

    attribute_map = {
        'firewall_instance_id': 'firewallInstanceId',
        'config': 'config',
        'deployment_status': 'deploymentStatus',
        'description': 'description'
    }

    def __init__(self, firewall_instance_id=None, config=None, deployment_status=None, description=None):  # noqa: E501
        """FirewallinstanceFirewallInstanceFirewallInstanceIdUuidBody - a model defined in Swagger"""  # noqa: E501
        self._firewall_instance_id = None
        self._config = None
        self._deployment_status = None
        self._description = None
        self.discriminator = None
        if firewall_instance_id is not None:
            self.firewall_instance_id = firewall_instance_id
        if config is not None:
            self.config = config
        if deployment_status is not None:
            self.deployment_status = deployment_status
        if description is not None:
            self.description = description

    @property
    def firewall_instance_id(self):
        """Gets the firewall_instance_id of this FirewallinstanceFirewallInstanceFirewallInstanceIdUuidBody.  # noqa: E501

        Unique ID of an object in RIME.  # noqa: E501

        :return: The firewall_instance_id of this FirewallinstanceFirewallInstanceFirewallInstanceIdUuidBody.  # noqa: E501
        :rtype: object
        """
        return self._firewall_instance_id

    @firewall_instance_id.setter
    def firewall_instance_id(self, firewall_instance_id):
        """Sets the firewall_instance_id of this FirewallinstanceFirewallInstanceFirewallInstanceIdUuidBody.

        Unique ID of an object in RIME.  # noqa: E501

        :param firewall_instance_id: The firewall_instance_id of this FirewallinstanceFirewallInstanceFirewallInstanceIdUuidBody.  # noqa: E501
        :type: object
        """

        self._firewall_instance_id = firewall_instance_id

    @property
    def config(self):
        """Gets the config of this FirewallinstanceFirewallInstanceFirewallInstanceIdUuidBody.  # noqa: E501


        :return: The config of this FirewallinstanceFirewallInstanceFirewallInstanceIdUuidBody.  # noqa: E501
        :rtype: GenerativefirewallFirewallRuleConfig
        """
        return self._config

    @config.setter
    def config(self, config):
        """Sets the config of this FirewallinstanceFirewallInstanceFirewallInstanceIdUuidBody.


        :param config: The config of this FirewallinstanceFirewallInstanceFirewallInstanceIdUuidBody.  # noqa: E501
        :type: GenerativefirewallFirewallRuleConfig
        """

        self._config = config

    @property
    def deployment_status(self):
        """Gets the deployment_status of this FirewallinstanceFirewallInstanceFirewallInstanceIdUuidBody.  # noqa: E501


        :return: The deployment_status of this FirewallinstanceFirewallInstanceFirewallInstanceIdUuidBody.  # noqa: E501
        :rtype: GenerativefirewallFirewallInstanceStatus
        """
        return self._deployment_status

    @deployment_status.setter
    def deployment_status(self, deployment_status):
        """Sets the deployment_status of this FirewallinstanceFirewallInstanceFirewallInstanceIdUuidBody.


        :param deployment_status: The deployment_status of this FirewallinstanceFirewallInstanceFirewallInstanceIdUuidBody.  # noqa: E501
        :type: GenerativefirewallFirewallInstanceStatus
        """

        self._deployment_status = deployment_status

    @property
    def description(self):
        """Gets the description of this FirewallinstanceFirewallInstanceFirewallInstanceIdUuidBody.  # noqa: E501

        Optional human-readable description of the firewall instance.  # noqa: E501

        :return: The description of this FirewallinstanceFirewallInstanceFirewallInstanceIdUuidBody.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this FirewallinstanceFirewallInstanceFirewallInstanceIdUuidBody.

        Optional human-readable description of the firewall instance.  # noqa: E501

        :param description: The description of this FirewallinstanceFirewallInstanceFirewallInstanceIdUuidBody.  # noqa: E501
        :type: str
        """

        self._description = description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FirewallinstanceFirewallInstanceFirewallInstanceIdUuidBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FirewallinstanceFirewallInstanceFirewallInstanceIdUuidBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TestrunresultTestCase(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'test_run_id': 'str',
        'features': 'list[str]',
        'test_batch_type': 'str',
        'status': 'RimeTestCaseStatus',
        'severity': 'RimeSeverity',
        'importance_score': 'float',
        'test_category': 'TestrunTestCategoryType',
        'category': 'str',
        'metrics': 'list[RimeTestMetric]',
        'url_safe_feature_id': 'str',
        'test_case_id': 'str',
        'display': 'TestrunresultTestCaseDisplay'
    }

    attribute_map = {
        'test_run_id': 'testRunId',
        'features': 'features',
        'test_batch_type': 'testBatchType',
        'status': 'status',
        'severity': 'severity',
        'importance_score': 'importanceScore',
        'test_category': 'testCategory',
        'category': 'category',
        'metrics': 'metrics',
        'url_safe_feature_id': 'urlSafeFeatureId',
        'test_case_id': 'testCaseId',
        'display': 'display'
    }

    def __init__(self, test_run_id=None, features=None, test_batch_type=None, status=None, severity=None, importance_score=None, test_category=None, category=None, metrics=None, url_safe_feature_id=None, test_case_id=None, display=None):  # noqa: E501
        """TestrunresultTestCase - a model defined in Swagger"""  # noqa: E501
        self._test_run_id = None
        self._features = None
        self._test_batch_type = None
        self._status = None
        self._severity = None
        self._importance_score = None
        self._test_category = None
        self._category = None
        self._metrics = None
        self._url_safe_feature_id = None
        self._test_case_id = None
        self._display = None
        self.discriminator = None
        if test_run_id is not None:
            self.test_run_id = test_run_id
        if features is not None:
            self.features = features
        if test_batch_type is not None:
            self.test_batch_type = test_batch_type
        if status is not None:
            self.status = status
        if severity is not None:
            self.severity = severity
        if importance_score is not None:
            self.importance_score = importance_score
        if test_category is not None:
            self.test_category = test_category
        if category is not None:
            self.category = category
        if metrics is not None:
            self.metrics = metrics
        if url_safe_feature_id is not None:
            self.url_safe_feature_id = url_safe_feature_id
        if test_case_id is not None:
            self.test_case_id = test_case_id
        if display is not None:
            self.display = display

    @property
    def test_run_id(self):
        """Gets the test_run_id of this TestrunresultTestCase.  # noqa: E501

        Uniquely specifies a Test Run.  # noqa: E501

        :return: The test_run_id of this TestrunresultTestCase.  # noqa: E501
        :rtype: str
        """
        return self._test_run_id

    @test_run_id.setter
    def test_run_id(self, test_run_id):
        """Sets the test_run_id of this TestrunresultTestCase.

        Uniquely specifies a Test Run.  # noqa: E501

        :param test_run_id: The test_run_id of this TestrunresultTestCase.  # noqa: E501
        :type: str
        """

        self._test_run_id = test_run_id

    @property
    def features(self):
        """Gets the features of this TestrunresultTestCase.  # noqa: E501

        The list of features used in the test case.  # noqa: E501

        :return: The features of this TestrunresultTestCase.  # noqa: E501
        :rtype: list[str]
        """
        return self._features

    @features.setter
    def features(self, features):
        """Sets the features of this TestrunresultTestCase.

        The list of features used in the test case.  # noqa: E501

        :param features: The features of this TestrunresultTestCase.  # noqa: E501
        :type: list[str]
        """

        self._features = features

    @property
    def test_batch_type(self):
        """Gets the test_batch_type of this TestrunresultTestCase.  # noqa: E501

        The type of test batch.  # noqa: E501

        :return: The test_batch_type of this TestrunresultTestCase.  # noqa: E501
        :rtype: str
        """
        return self._test_batch_type

    @test_batch_type.setter
    def test_batch_type(self, test_batch_type):
        """Sets the test_batch_type of this TestrunresultTestCase.

        The type of test batch.  # noqa: E501

        :param test_batch_type: The test_batch_type of this TestrunresultTestCase.  # noqa: E501
        :type: str
        """

        self._test_batch_type = test_batch_type

    @property
    def status(self):
        """Gets the status of this TestrunresultTestCase.  # noqa: E501


        :return: The status of this TestrunresultTestCase.  # noqa: E501
        :rtype: RimeTestCaseStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this TestrunresultTestCase.


        :param status: The status of this TestrunresultTestCase.  # noqa: E501
        :type: RimeTestCaseStatus
        """

        self._status = status

    @property
    def severity(self):
        """Gets the severity of this TestrunresultTestCase.  # noqa: E501


        :return: The severity of this TestrunresultTestCase.  # noqa: E501
        :rtype: RimeSeverity
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """Sets the severity of this TestrunresultTestCase.


        :param severity: The severity of this TestrunresultTestCase.  # noqa: E501
        :type: RimeSeverity
        """

        self._severity = severity

    @property
    def importance_score(self):
        """Gets the importance_score of this TestrunresultTestCase.  # noqa: E501

        The model impact of the test case.  # noqa: E501

        :return: The importance_score of this TestrunresultTestCase.  # noqa: E501
        :rtype: float
        """
        return self._importance_score

    @importance_score.setter
    def importance_score(self, importance_score):
        """Sets the importance_score of this TestrunresultTestCase.

        The model impact of the test case.  # noqa: E501

        :param importance_score: The importance_score of this TestrunresultTestCase.  # noqa: E501
        :type: float
        """

        self._importance_score = importance_score

    @property
    def test_category(self):
        """Gets the test_category of this TestrunresultTestCase.  # noqa: E501


        :return: The test_category of this TestrunresultTestCase.  # noqa: E501
        :rtype: TestrunTestCategoryType
        """
        return self._test_category

    @test_category.setter
    def test_category(self, test_category):
        """Sets the test_category of this TestrunresultTestCase.


        :param test_category: The test_category of this TestrunresultTestCase.  # noqa: E501
        :type: TestrunTestCategoryType
        """

        self._test_category = test_category

    @property
    def category(self):
        """Gets the category of this TestrunresultTestCase.  # noqa: E501

        The string field `category` is deprecated in v2.1 and will be removed in v2.3. Please use the enum field test_category instead, which provides the same info.  # noqa: E501

        :return: The category of this TestrunresultTestCase.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this TestrunresultTestCase.

        The string field `category` is deprecated in v2.1 and will be removed in v2.3. Please use the enum field test_category instead, which provides the same info.  # noqa: E501

        :param category: The category of this TestrunresultTestCase.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def metrics(self):
        """Gets the metrics of this TestrunresultTestCase.  # noqa: E501


        :return: The metrics of this TestrunresultTestCase.  # noqa: E501
        :rtype: list[RimeTestMetric]
        """
        return self._metrics

    @metrics.setter
    def metrics(self, metrics):
        """Sets the metrics of this TestrunresultTestCase.


        :param metrics: The metrics of this TestrunresultTestCase.  # noqa: E501
        :type: list[RimeTestMetric]
        """

        self._metrics = metrics

    @property
    def url_safe_feature_id(self):
        """Gets the url_safe_feature_id of this TestrunresultTestCase.  # noqa: E501

        Optional URL-safe feature ID if the test case is associated with a feature. This may be empty for modalities that do not have features or test cases that pertain to two or more features, such as subset tests.  # noqa: E501

        :return: The url_safe_feature_id of this TestrunresultTestCase.  # noqa: E501
        :rtype: str
        """
        return self._url_safe_feature_id

    @url_safe_feature_id.setter
    def url_safe_feature_id(self, url_safe_feature_id):
        """Sets the url_safe_feature_id of this TestrunresultTestCase.

        Optional URL-safe feature ID if the test case is associated with a feature. This may be empty for modalities that do not have features or test cases that pertain to two or more features, such as subset tests.  # noqa: E501

        :param url_safe_feature_id: The url_safe_feature_id of this TestrunresultTestCase.  # noqa: E501
        :type: str
        """

        self._url_safe_feature_id = url_safe_feature_id

    @property
    def test_case_id(self):
        """Gets the test_case_id of this TestrunresultTestCase.  # noqa: E501

        Together with the Test Run ID and the test batch type, this forms the primary key for the test case.  # noqa: E501

        :return: The test_case_id of this TestrunresultTestCase.  # noqa: E501
        :rtype: str
        """
        return self._test_case_id

    @test_case_id.setter
    def test_case_id(self, test_case_id):
        """Sets the test_case_id of this TestrunresultTestCase.

        Together with the Test Run ID and the test batch type, this forms the primary key for the test case.  # noqa: E501

        :param test_case_id: The test_case_id of this TestrunresultTestCase.  # noqa: E501
        :type: str
        """

        self._test_case_id = test_case_id

    @property
    def display(self):
        """Gets the display of this TestrunresultTestCase.  # noqa: E501


        :return: The display of this TestrunresultTestCase.  # noqa: E501
        :rtype: TestrunresultTestCaseDisplay
        """
        return self._display

    @display.setter
    def display(self, display):
        """Sets the display of this TestrunresultTestCase.


        :param display: The display of this TestrunresultTestCase.  # noqa: E501
        :type: TestrunresultTestCaseDisplay
        """

        self._display = display

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TestrunresultTestCase, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TestrunresultTestCase):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ModelModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'model_id': 'RimeUUID',
        'project_ids': 'list[RimeUUID]',
        'creator_id': 'RimeUUID',
        'creation_time': 'datetime',
        'external_id': 'str',
        'user_metadata': 'RegistryMetadata',
        'model_info': 'RegistryModelInfo',
        'validity_status': 'RegistryValidityStatus',
        'integration_id': 'RimeUUID',
        'model_endpoint_integration_id': 'RimeUUID',
        'validity_status_message': 'str'
    }

    attribute_map = {
        'name': 'name',
        'model_id': 'modelId',
        'project_ids': 'projectIds',
        'creator_id': 'creatorId',
        'creation_time': 'creationTime',
        'external_id': 'externalId',
        'user_metadata': 'userMetadata',
        'model_info': 'modelInfo',
        'validity_status': 'validityStatus',
        'integration_id': 'integrationId',
        'model_endpoint_integration_id': 'modelEndpointIntegrationId',
        'validity_status_message': 'validityStatusMessage'
    }

    def __init__(self, name=None, model_id=None, project_ids=None, creator_id=None, creation_time=None, external_id=None, user_metadata=None, model_info=None, validity_status=None, integration_id=None, model_endpoint_integration_id=None, validity_status_message=None):  # noqa: E501
        """ModelModel - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._model_id = None
        self._project_ids = None
        self._creator_id = None
        self._creation_time = None
        self._external_id = None
        self._user_metadata = None
        self._model_info = None
        self._validity_status = None
        self._integration_id = None
        self._model_endpoint_integration_id = None
        self._validity_status_message = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if model_id is not None:
            self.model_id = model_id
        if project_ids is not None:
            self.project_ids = project_ids
        if creator_id is not None:
            self.creator_id = creator_id
        if creation_time is not None:
            self.creation_time = creation_time
        if external_id is not None:
            self.external_id = external_id
        if user_metadata is not None:
            self.user_metadata = user_metadata
        if model_info is not None:
            self.model_info = model_info
        if validity_status is not None:
            self.validity_status = validity_status
        if integration_id is not None:
            self.integration_id = integration_id
        if model_endpoint_integration_id is not None:
            self.model_endpoint_integration_id = model_endpoint_integration_id
        if validity_status_message is not None:
            self.validity_status_message = validity_status_message

    @property
    def name(self):
        """Gets the name of this ModelModel.  # noqa: E501

        Name and model_id are both enforced to be unique. Name is user specified. Model_id is internally generated.  # noqa: E501

        :return: The name of this ModelModel.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ModelModel.

        Name and model_id are both enforced to be unique. Name is user specified. Model_id is internally generated.  # noqa: E501

        :param name: The name of this ModelModel.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def model_id(self):
        """Gets the model_id of this ModelModel.  # noqa: E501


        :return: The model_id of this ModelModel.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._model_id

    @model_id.setter
    def model_id(self, model_id):
        """Sets the model_id of this ModelModel.


        :param model_id: The model_id of this ModelModel.  # noqa: E501
        :type: RimeUUID
        """

        self._model_id = model_id

    @property
    def project_ids(self):
        """Gets the project_ids of this ModelModel.  # noqa: E501

        For now, a model will only have one project_id associated with it. We make this an array to allow model's to be shared in the future.  # noqa: E501

        :return: The project_ids of this ModelModel.  # noqa: E501
        :rtype: list[RimeUUID]
        """
        return self._project_ids

    @project_ids.setter
    def project_ids(self, project_ids):
        """Sets the project_ids of this ModelModel.

        For now, a model will only have one project_id associated with it. We make this an array to allow model's to be shared in the future.  # noqa: E501

        :param project_ids: The project_ids of this ModelModel.  # noqa: E501
        :type: list[RimeUUID]
        """

        self._project_ids = project_ids

    @property
    def creator_id(self):
        """Gets the creator_id of this ModelModel.  # noqa: E501


        :return: The creator_id of this ModelModel.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._creator_id

    @creator_id.setter
    def creator_id(self, creator_id):
        """Sets the creator_id of this ModelModel.


        :param creator_id: The creator_id of this ModelModel.  # noqa: E501
        :type: RimeUUID
        """

        self._creator_id = creator_id

    @property
    def creation_time(self):
        """Gets the creation_time of this ModelModel.  # noqa: E501


        :return: The creation_time of this ModelModel.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this ModelModel.


        :param creation_time: The creation_time of this ModelModel.  # noqa: E501
        :type: datetime
        """

        self._creation_time = creation_time

    @property
    def external_id(self):
        """Gets the external_id of this ModelModel.  # noqa: E501

        external_id is an optional way for a user to identify the model with their own Model IDs.  # noqa: E501

        :return: The external_id of this ModelModel.  # noqa: E501
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this ModelModel.

        external_id is an optional way for a user to identify the model with their own Model IDs.  # noqa: E501

        :param external_id: The external_id of this ModelModel.  # noqa: E501
        :type: str
        """

        self._external_id = external_id

    @property
    def user_metadata(self):
        """Gets the user_metadata of this ModelModel.  # noqa: E501


        :return: The user_metadata of this ModelModel.  # noqa: E501
        :rtype: RegistryMetadata
        """
        return self._user_metadata

    @user_metadata.setter
    def user_metadata(self, user_metadata):
        """Sets the user_metadata of this ModelModel.


        :param user_metadata: The user_metadata of this ModelModel.  # noqa: E501
        :type: RegistryMetadata
        """

        self._user_metadata = user_metadata

    @property
    def model_info(self):
        """Gets the model_info of this ModelModel.  # noqa: E501


        :return: The model_info of this ModelModel.  # noqa: E501
        :rtype: RegistryModelInfo
        """
        return self._model_info

    @model_info.setter
    def model_info(self, model_info):
        """Sets the model_info of this ModelModel.


        :param model_info: The model_info of this ModelModel.  # noqa: E501
        :type: RegistryModelInfo
        """

        self._model_info = model_info

    @property
    def validity_status(self):
        """Gets the validity_status of this ModelModel.  # noqa: E501


        :return: The validity_status of this ModelModel.  # noqa: E501
        :rtype: RegistryValidityStatus
        """
        return self._validity_status

    @validity_status.setter
    def validity_status(self, validity_status):
        """Sets the validity_status of this ModelModel.


        :param validity_status: The validity_status of this ModelModel.  # noqa: E501
        :type: RegistryValidityStatus
        """

        self._validity_status = validity_status

    @property
    def integration_id(self):
        """Gets the integration_id of this ModelModel.  # noqa: E501


        :return: The integration_id of this ModelModel.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._integration_id

    @integration_id.setter
    def integration_id(self, integration_id):
        """Sets the integration_id of this ModelModel.


        :param integration_id: The integration_id of this ModelModel.  # noqa: E501
        :type: RimeUUID
        """

        self._integration_id = integration_id

    @property
    def model_endpoint_integration_id(self):
        """Gets the model_endpoint_integration_id of this ModelModel.  # noqa: E501


        :return: The model_endpoint_integration_id of this ModelModel.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._model_endpoint_integration_id

    @model_endpoint_integration_id.setter
    def model_endpoint_integration_id(self, model_endpoint_integration_id):
        """Sets the model_endpoint_integration_id of this ModelModel.


        :param model_endpoint_integration_id: The model_endpoint_integration_id of this ModelModel.  # noqa: E501
        :type: RimeUUID
        """

        self._model_endpoint_integration_id = model_endpoint_integration_id

    @property
    def validity_status_message(self):
        """Gets the validity_status_message of this ModelModel.  # noqa: E501

        Information about the validity status of the model, such as why it is invalid. A Case where this would be populated is when the ValidityStatus is not explicitly set to valid by the XP validation task and additional details are required to convey to the user why the model is not valid.  # noqa: E501

        :return: The validity_status_message of this ModelModel.  # noqa: E501
        :rtype: str
        """
        return self._validity_status_message

    @validity_status_message.setter
    def validity_status_message(self, validity_status_message):
        """Sets the validity_status_message of this ModelModel.

        Information about the validity status of the model, such as why it is invalid. A Case where this would be populated is when the ValidityStatus is not explicitly set to valid by the XP validation task and additional details are required to convey to the user why the model is not valid.  # noqa: E501

        :param validity_status_message: The validity_status_message of this ModelModel.  # noqa: E501
        :type: str
        """

        self._validity_status_message = validity_status_message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ModelModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ProjectIdUuidDatasetBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'project_id': 'object',
        'name': 'str',
        'metadata': 'RegistryMetadata',
        'integration_id': 'RimeUUID',
        'data_info': 'RegistryDataInfo',
        'ct_info': 'DatasetCTInfo',
        'skip_validation': 'bool',
        'agent_id': 'RimeUUID'
    }

    attribute_map = {
        'project_id': 'projectId',
        'name': 'name',
        'metadata': 'metadata',
        'integration_id': 'integrationId',
        'data_info': 'dataInfo',
        'ct_info': 'ctInfo',
        'skip_validation': 'skipValidation',
        'agent_id': 'agentId'
    }

    def __init__(self, project_id=None, name=None, metadata=None, integration_id=None, data_info=None, ct_info=None, skip_validation=None, agent_id=None):  # noqa: E501
        """ProjectIdUuidDatasetBody - a model defined in Swagger"""  # noqa: E501
        self._project_id = None
        self._name = None
        self._metadata = None
        self._integration_id = None
        self._data_info = None
        self._ct_info = None
        self._skip_validation = None
        self._agent_id = None
        self.discriminator = None
        if project_id is not None:
            self.project_id = project_id
        self.name = name
        if metadata is not None:
            self.metadata = metadata
        if integration_id is not None:
            self.integration_id = integration_id
        if data_info is not None:
            self.data_info = data_info
        if ct_info is not None:
            self.ct_info = ct_info
        if skip_validation is not None:
            self.skip_validation = skip_validation
        if agent_id is not None:
            self.agent_id = agent_id

    @property
    def project_id(self):
        """Gets the project_id of this ProjectIdUuidDatasetBody.  # noqa: E501

        Uniquely specifies a Project.  # noqa: E501

        :return: The project_id of this ProjectIdUuidDatasetBody.  # noqa: E501
        :rtype: object
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this ProjectIdUuidDatasetBody.

        Uniquely specifies a Project.  # noqa: E501

        :param project_id: The project_id of this ProjectIdUuidDatasetBody.  # noqa: E501
        :type: object
        """

        self._project_id = project_id

    @property
    def name(self):
        """Gets the name of this ProjectIdUuidDatasetBody.  # noqa: E501

        Unique name of the Dataset.  # noqa: E501

        :return: The name of this ProjectIdUuidDatasetBody.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ProjectIdUuidDatasetBody.

        Unique name of the Dataset.  # noqa: E501

        :param name: The name of this ProjectIdUuidDatasetBody.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def metadata(self):
        """Gets the metadata of this ProjectIdUuidDatasetBody.  # noqa: E501


        :return: The metadata of this ProjectIdUuidDatasetBody.  # noqa: E501
        :rtype: RegistryMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this ProjectIdUuidDatasetBody.


        :param metadata: The metadata of this ProjectIdUuidDatasetBody.  # noqa: E501
        :type: RegistryMetadata
        """

        self._metadata = metadata

    @property
    def integration_id(self):
        """Gets the integration_id of this ProjectIdUuidDatasetBody.  # noqa: E501


        :return: The integration_id of this ProjectIdUuidDatasetBody.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._integration_id

    @integration_id.setter
    def integration_id(self, integration_id):
        """Sets the integration_id of this ProjectIdUuidDatasetBody.


        :param integration_id: The integration_id of this ProjectIdUuidDatasetBody.  # noqa: E501
        :type: RimeUUID
        """

        self._integration_id = integration_id

    @property
    def data_info(self):
        """Gets the data_info of this ProjectIdUuidDatasetBody.  # noqa: E501


        :return: The data_info of this ProjectIdUuidDatasetBody.  # noqa: E501
        :rtype: RegistryDataInfo
        """
        return self._data_info

    @data_info.setter
    def data_info(self, data_info):
        """Sets the data_info of this ProjectIdUuidDatasetBody.


        :param data_info: The data_info of this ProjectIdUuidDatasetBody.  # noqa: E501
        :type: RegistryDataInfo
        """

        self._data_info = data_info

    @property
    def ct_info(self):
        """Gets the ct_info of this ProjectIdUuidDatasetBody.  # noqa: E501


        :return: The ct_info of this ProjectIdUuidDatasetBody.  # noqa: E501
        :rtype: DatasetCTInfo
        """
        return self._ct_info

    @ct_info.setter
    def ct_info(self, ct_info):
        """Sets the ct_info of this ProjectIdUuidDatasetBody.


        :param ct_info: The ct_info of this ProjectIdUuidDatasetBody.  # noqa: E501
        :type: DatasetCTInfo
        """

        self._ct_info = ct_info

    @property
    def skip_validation(self):
        """Gets the skip_validation of this ProjectIdUuidDatasetBody.  # noqa: E501

        The parameter is deprecated since 2.7, and does not have any effect. Will always validate the dataset you are registering. Validation ensures that the dataset is valid for Robust Intelligence's systems.  # noqa: E501

        :return: The skip_validation of this ProjectIdUuidDatasetBody.  # noqa: E501
        :rtype: bool
        """
        return self._skip_validation

    @skip_validation.setter
    def skip_validation(self, skip_validation):
        """Sets the skip_validation of this ProjectIdUuidDatasetBody.

        The parameter is deprecated since 2.7, and does not have any effect. Will always validate the dataset you are registering. Validation ensures that the dataset is valid for Robust Intelligence's systems.  # noqa: E501

        :param skip_validation: The skip_validation of this ProjectIdUuidDatasetBody.  # noqa: E501
        :type: bool
        """

        self._skip_validation = skip_validation

    @property
    def agent_id(self):
        """Gets the agent_id of this ProjectIdUuidDatasetBody.  # noqa: E501


        :return: The agent_id of this ProjectIdUuidDatasetBody.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._agent_id

    @agent_id.setter
    def agent_id(self, agent_id):
        """Sets the agent_id of this ProjectIdUuidDatasetBody.


        :param agent_id: The agent_id of this ProjectIdUuidDatasetBody.  # noqa: E501
        :type: RimeUUID
        """

        self._agent_id = agent_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProjectIdUuidDatasetBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProjectIdUuidDatasetBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



"""Setup file for package."""
import re
from pathlib import Path
from subprocess import CalledProcessError, run

from setuptools import find_packages, setup

CUR_DIR = Path(__file__).parent


# Note: this should only be used to load objects during setup.
# This should not be used for anything at wheel installation time, because the
# paths that work for setup in the `rime` repo will not work when installing
# into another computer with a different file system.
def _get_git_root() -> Path:
    git_root = run(
        ["git", "rev-parse", "--show-toplevel"],
        capture_output=True,
        encoding="utf-8",
    ).stdout.strip()
    return Path(git_root)


git_root_path = _get_git_root()


# We want the semantic version to come in the form
# of `git describe`.  In edge cases we might run this command in
# a git repo with a shallow history which will cause an error.
# In that situation we fall back to the string in the fw_version.txt
# file which is updated every time we cut a release.
#
# Our naming scheme is at odds with PEP 440, so we have to
# make it conforming but using "+" to join the public
# identify (fw_version.txt) with our local identifier, which
# is the string that git describe appends.
with open("../../version.txt", encoding="utf-8") as f:
    version_txt = f.read().strip()
try:
    rawver = run(
        ["git", "describe", "HEAD", "--match", "[0-9]*.[0-9]*.[0-9]*"],
        check=True,
        encoding="utf-8",
        capture_output=True,
    ).stdout.strip()
    localver = re.split(version_txt, rawver)[-1]
    # locaver is not empty and starts with "-" on devlopment releases
    if localver:
        localver = "+" + localver[1:]
    semver = version_txt + localver
except (CalledProcessError, AttributeError):
    semver = version_txt

with open(CUR_DIR / "README.md", "r") as fh:
    long_description = fh.read()

# We want the semantic version to come in the form
# of `git describe`.  In edge cases we might run this command in
# a git repo with a shallow history which will cause an error.
# In that situation we fall back to the string in the version.txt
# file which is updated every time we cut a release.
#
# Our naming scheme is at odds with PEP 440, so we have to
# make it conforming but using "+" to join the public
# identify (version.txt) with our local identifier, which
# is the string that git describe appends.
with open(git_root_path / "version.txt", encoding="utf-8") as f:
    version_txt = f.read().strip()
try:
    rawver = run(
        ["git", "describe", "HEAD"], check=True, encoding="utf-8", capture_output=True
    ).stdout.strip()
    localver = re.split(version_txt, rawver)[-1]
    # locaver is not empty and starts with "-" on devlopment releases
    if localver:
        localver = "+" + localver[1:]
    semver = version_txt + localver
except (CalledProcessError, AttributeError):
    semver = version_txt

print(f"version is {semver}")


setup(
    name="rime_sdk",
    version=semver,
    packages=find_packages(include=["rime_sdk*"]),
    description="Package to programmatically access a RIME deployment",
    long_description=long_description,
    long_description_content_type="text/markdown",
    install_requires=[
        # Note: click is a dependency of `requests` but has to be pinned here
        # due to https://github.com/psf/black/issues/2964 .
        "click>=8.0.1,<8.1.4",
        "deprecated>=1.0.0,<2.0.0",
        "semver>=2.10.0,<3.0.0",
        "simplejson",
        "pandas>=1.1.0,<1.5.0",
        "requests>=2.0.0",
        "tqdm",
        "importlib_metadata",
        "protobuf",
        # below reqs are for data_format_check
        "schema",
        "numpy",
    ],
    python_requires=">=3.6",
    license="OSI Approved :: Apache Software License",
    entry_points={
        "console_scripts": [
            "rime-data-format-check=rime_sdk.data_format_check.cli:main",
        ]
    },
)



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DatasetCTInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'firewall_id': 'RimeUUID',
        'start_time': 'datetime',
        'end_time': 'datetime',
        'ct_dataset_type': 'DatasetCTDatasetType'
    }

    attribute_map = {
        'firewall_id': 'firewallId',
        'start_time': 'startTime',
        'end_time': 'endTime',
        'ct_dataset_type': 'ctDatasetType'
    }

    def __init__(self, firewall_id=None, start_time=None, end_time=None, ct_dataset_type=None):  # noqa: E501
        """DatasetCTInfo - a model defined in Swagger"""  # noqa: E501
        self._firewall_id = None
        self._start_time = None
        self._end_time = None
        self._ct_dataset_type = None
        self.discriminator = None
        if firewall_id is not None:
            self.firewall_id = firewall_id
        self.start_time = start_time
        self.end_time = end_time
        if ct_dataset_type is not None:
            self.ct_dataset_type = ct_dataset_type

    @property
    def firewall_id(self):
        """Gets the firewall_id of this DatasetCTInfo.  # noqa: E501


        :return: The firewall_id of this DatasetCTInfo.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._firewall_id

    @firewall_id.setter
    def firewall_id(self, firewall_id):
        """Sets the firewall_id of this DatasetCTInfo.


        :param firewall_id: The firewall_id of this DatasetCTInfo.  # noqa: E501
        :type: RimeUUID
        """

        self._firewall_id = firewall_id

    @property
    def start_time(self):
        """Gets the start_time of this DatasetCTInfo.  # noqa: E501

        Start and end time are the start and end time of this dataset.  # noqa: E501

        :return: The start_time of this DatasetCTInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this DatasetCTInfo.

        Start and end time are the start and end time of this dataset.  # noqa: E501

        :param start_time: The start_time of this DatasetCTInfo.  # noqa: E501
        :type: datetime
        """
        if start_time is None:
            raise ValueError("Invalid value for `start_time`, must not be `None`")  # noqa: E501

        self._start_time = start_time

    @property
    def end_time(self):
        """Gets the end_time of this DatasetCTInfo.  # noqa: E501


        :return: The end_time of this DatasetCTInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this DatasetCTInfo.


        :param end_time: The end_time of this DatasetCTInfo.  # noqa: E501
        :type: datetime
        """
        if end_time is None:
            raise ValueError("Invalid value for `end_time`, must not be `None`")  # noqa: E501

        self._end_time = end_time

    @property
    def ct_dataset_type(self):
        """Gets the ct_dataset_type of this DatasetCTInfo.  # noqa: E501


        :return: The ct_dataset_type of this DatasetCTInfo.  # noqa: E501
        :rtype: DatasetCTDatasetType
        """
        return self._ct_dataset_type

    @ct_dataset_type.setter
    def ct_dataset_type(self, ct_dataset_type):
        """Sets the ct_dataset_type of this DatasetCTInfo.


        :param ct_dataset_type: The ct_dataset_type of this DatasetCTInfo.  # noqa: E501
        :type: DatasetCTDatasetType
        """

        self._ct_dataset_type = ct_dataset_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DatasetCTInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DatasetCTInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
